.. _api:

Detailed API
============

.. toctree::
    :maxdepth: 2

    api/detector_classes.rst
    api/obs_classes.rst
    api/simul.rst
    api/reduction.rst
    api/utils.rst
    api/webbpsf_ext.rst